@@ -159,7 +159,9 @@ class ExplicitFileSource(object):
                 if os.path.isdir(src):
                     for dirpath, dirnames, filenames in os.walk(src, topdown=True):
                         for fn in filenames:
-                            dst_fileparts = [dst, filename] + dirnames + [fn]
+                            dst_fileparts = (
+                                [dst, filename] + [os.path.relpath(dirpath, src)] + [fn]
+                            )
                             dst_filepath = os.path.join(*dst_fileparts)
                             yield (
                                 os.path.join(dirpath, fn),
